==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/SummaryRowSectionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SummaryRowDescriptionMetadata } from "./SummaryRowDescriptionMetadata";
import { SummaryRowSectionDescription } from "./SummaryRowSectionDescription";
/**
 * @hidden
 */
var SummaryRowSectionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SummaryRowSectionDescriptionMetadata, _super);
    function SummaryRowSectionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SummaryRowSectionDescriptionMetadata.b = function (a) {
        if (SummaryRowSectionDescriptionMetadata.a == null) {
            SummaryRowSectionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SummaryRowSectionDescriptionMetadata.c(SummaryRowSectionDescriptionMetadata.a);
        }
        if (a.j(SummaryRowSectionDescriptionMetadata.a)) {
            return;
        }
        a.y(SummaryRowSectionDescriptionMetadata.a);
    };
    SummaryRowSectionDescriptionMetadata.c = function (a) {
        SummaryRowDescriptionMetadata.c(a);
    };
    SummaryRowSectionDescriptionMetadata.d = function (a) {
        SummaryRowSectionDescriptionMetadata.b(a);
        a.aa("SummaryRowSection", function () { return new SummaryRowSectionDescription(); });
        a.z("SummaryRowSection", SummaryRowSectionDescriptionMetadata.a);
    };
    SummaryRowSectionDescriptionMetadata.$t = markType(SummaryRowSectionDescriptionMetadata, 'SummaryRowSectionDescriptionMetadata');
    SummaryRowSectionDescriptionMetadata.a = null;
    return SummaryRowSectionDescriptionMetadata;
}(Base));
export { SummaryRowSectionDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/SummaryRowSectionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SummaryRowDescriptionMetadata } from "./SummaryRowDescriptionMetadata";
import { SummaryRowSectionDescription } from "./SummaryRowSectionDescription";
/**
 * @hidden
 */
var SummaryRowSectionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SummaryRowSectionDescriptionMetadata, _super);
    function SummaryRowSectionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SummaryRowSectionDescriptionMetadata.b = function (a) {
        if (SummaryRowSectionDescriptionMetadata.a == null) {
            SummaryRowSectionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SummaryRowSectionDescriptionMetadata.c(SummaryRowSectionDescriptionMetadata.a);
        }
        if (a.k(SummaryRowSectionDescriptionMetadata.a)) {
            return;
        }
        a.aa(SummaryRowSectionDescriptionMetadata.a);
    };
    SummaryRowSectionDescriptionMetadata.c = function (a) {
        SummaryRowDescriptionMetadata.c(a);
    };
    SummaryRowSectionDescriptionMetadata.d = function (a) {
        SummaryRowSectionDescriptionMetadata.b(a);
        a.ac("SummaryRowSection", function () { return new SummaryRowSectionDescription(); });
        a.ab("SummaryRowSection", SummaryRowSectionDescriptionMetadata.a);
    };
    SummaryRowSectionDescriptionMetadata.$t = markType(SummaryRowSectionDescriptionMetadata, 'SummaryRowSectionDescriptionMetadata');
    SummaryRowSectionDescriptionMetadata.a = null;
    return SummaryRowSectionDescriptionMetadata;
}(Base));
export { SummaryRowSectionDescriptionMetadata };
